The CPHD 0.3 VectorParameters object
====================================

.. automodule:: sarpy.io.phase_history.cphd0_3_elements.VectorParameters
    :members:
    :show-inheritance:
    :inherited-members:
